@@ -91,15 +91,24 @@ class AnyUrlField(models.CharField):
 
         return AnyUrlValue.from_db_value(value, self._static_registry)
 
+
     def get_prep_value(self, value):
         if isinstance(value, basestring):
             # Happens with south migration
             return value
+        elif value is None:
+            return None if self.null else ''
         else:
             # Convert back to string
             return value.to_db_value()
 
 
+    def value_to_string(self, obj):
+        # For dumpdata
+        value = self._get_val_from_obj(obj)
+        return self.get_prep_value(value)
+
+
     def validate(self, value, model_instance):
         # Final validation of the field, before storing in the DB.
         super(AnyUrlField, self).validate(value, model_instance)
